import { __awaiter, __decorate } from "tslib";
import { LifecycleMixin } from '@genesislcap/foundation-utils';
import { customElement, FoundationElement } from '@genesislcap/web-core';
import { first } from 'rxjs';
import { FDC3 } from '../fdc3';
/**
 * fdc3-system-channel-listener
 * Util element to listen to the context on a fdc3 app channel
 * @alpha
 */
let Fdc3IntentListener = class Fdc3IntentListener extends LifecycleMixin(FoundationElement) {
    constructor() {
        super(...arguments);
        this.intentConfig = [];
    }
    connectedCallback() {
        super.connectedCallback();
        this.fdc3.isReady$.pipe(first()).subscribe(() => __awaiter(this, void 0, void 0, function* () {
            if (this.intentConfig) {
                this.addIntentListeners(this.intentConfig);
            }
        }));
    }
    deepClone() {
        const copy = super.deepClone();
        if (this.intentConfig) {
            copy.intentConfig = this.intentConfig.map((c) => {
                const copyConfig = Object.assign({}, c);
                if (c.callback) {
                    copyConfig.callback = c.callback.bind(this);
                }
                return copyConfig;
            });
        }
        return copy;
    }
    addIntentListeners(intentConfig) {
        const intentListeners = intentConfig.reduce((listenerMap, intent) => {
            listenerMap.set(intent.intent, intent.callback);
            return listenerMap;
        }, new Map());
        this.fdc3.addIntentListeners(intentListeners);
    }
};
__decorate([
    FDC3
], Fdc3IntentListener.prototype, "fdc3", void 0);
Fdc3IntentListener = __decorate([
    customElement({
        name: 'fdc3-intent-listener',
    })
], Fdc3IntentListener);
export { Fdc3IntentListener };
